# Copyright 2022 Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)

from dateutil.relativedelta import relativedelta

from odoo import api, fields, models


class AlterincubClass(models.Model):
    _name = "alterincub.class"
    _description = "Promotions Alter'Incub"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    name = fields.Char(
        "Nom de la promotion",
        compute="_compute_name",
        store=True,
    )
    active = fields.Boolean(
        "Actif",
        default=True,
    )
    start_date = fields.Date("Date de début", required=True)
    stop_date = fields.Date("Date de fin", required=True)
    duration_id = fields.Many2one(
        comodel_name="alterincub.class.duration",
        string="Durée (en mois)",
        ondelete="restrict",
        required=True,
    )
    area_id = fields.Many2one(
        comodel_name="alterincub.area",
        string="Territoire",
        ondelete="restrict",
        required=True,
    )
    project_ids = fields.One2many(
        comodel_name="res.partner",
        inverse_name="class_id",
        string="Projets",
        domain=[("contact_type", "=", "project"), ("is_company", "=", True)],
    )
    project_nb = fields.Integer(
        string="Nombre de projets", compute="_compute_project_nb", store=True, default=0
    )
    cloud_url = fields.Char("URL Nextcloud")

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------
    @api.depends("start_date", "area_id", "area_id.name")
    def _compute_name(self):
        for a_class in self:
            if a_class.start_date and a_class.area_id:
                a_class.name = (
                    fields.Date.to_string(a_class.start_date)
                    + " - "
                    + a_class.area_id.name
                )
            else:
                a_class.name = ""

    @api.depends("project_ids")
    def _compute_project_nb(self):
        for class_id in self:
            class_id.project_nb = len(class_id.project_ids)

    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------
    @api.onchange("duration_id")
    def _onchange_duration(self):
        if self.start_date and self.duration_id:
            self.stop_date = self.start_date + relativedelta(
                months=self.duration_id.duration
            )
