# Copyright 2022 Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)


from odoo import api, fields, models
from odoo.osv import expression


class AlterincubDepartment(models.Model):
    _name = "alterincub.department"
    _description = "Départements Alter'Incub"
    _rec_name = "display_name"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    code = fields.Char("N°", required=True)
    name = fields.Char("Nom", required=True)
    area_id = fields.Many2one(
        comodel_name="alterincub.area",
        string="Territoire",
        ondelete="restrict",
        required=True,
    )
    display_name = fields.Char(compute="_compute_display_name")

    # ------------------------------------------------------
    # Computed fields
    # ------------------------------------------------------
    def _compute_display_name(self):
        for d in self:
            d.display_name = d.code + " - " + d.name

    # ------------------------------------------------------
    # Override ORM
    # ------------------------------------------------------
    @api.model
    def _name_search(
        self, name, args=None, operator="ilike", limit=100, name_get_uid=None
    ):
        args = args or []
        domain = ["|", ("name", operator, name), ("code", "ilike", name)]
        return self._search(
            expression.AND([domain, args]), limit=limit, access_rights_uid=name_get_uid
        )
