# Copyright 2022 Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)

from datetime import date

from odoo.exceptions import UserError
from odoo.tests import Form

from odoo.addons.alterincub_partner.tests.common import TestAlterincubPartnerCommon


class TestAlterincubResPartner(TestAlterincubPartnerCommon):
    # ------------------------------------------------------
    # Project
    # ------------------------------------------------------
    def test_project_form(self):
        partner_form = Form(self.project_1.with_user(self.env.user))
        partner_form.save()

    def test_project_write_lost(self):
        with self.assertRaises(UserError):
            self.project_lost.project_state = "1_incub"
        with self.assertRaises(UserError):
            self.project_1.project_state = "8_lost"

    def test_project_exit_wizard(self):
        wizard = self.env["alterincub.exit.project.wizard"].create(
            {
                "partner_id": self.project_1.id,
                "end_reason_id": self.ref(
                    "alterincub_partner.alterincub_end_reason_01"
                ),
                "end_reason_comment": "La flemme",
                "stop_date": "2022-06-02",
            }
        )
        wizard.set_exit_project()
        self.assertEqual(self.project_1.project_state, "8_lost")
        self.assertEqual(self.project_1.stop_date, date(2022, 6, 2))
        self.assertEqual(self.project_1.end_reason_comment, "La flemme")
        self.assertEqual(
            self.project_1.end_reason_id,
            self.browse_ref("alterincub_partner.alterincub_end_reason_01"),
        )

    # ------------------------------------------------------
    # Provider
    # ------------------------------------------------------
    def test_provider_form(self):
        partner_form = Form(self.provider_vat.with_user(self.env.user))
        partner_form.save()

    # ------------------------------------------------------
    # Childs
    # ------------------------------------------------------
    def test_child_incubated(self):
        partner_form = Form(self.project_1.with_user(self.env.user))
        # check incubated field
        with partner_form.child_ids.new() as child:
            child.lastname = "First"
            child.firstname = "Child"
            self.assertEqual(child.is_incubated, True)
            self.assertEqual(child.is_provider, False)

    def test_child_provider(self):
        partner_form = Form(self.provider_vat.with_user(self.env.user))
        # check provider field
        with partner_form.child_ids.new() as child:
            child.lastname = "Provider"
            child.firstname = "Child"
            self.assertEqual(child.is_incubated, False)
            self.assertEqual(child.is_provider, True)
