# Copyright 2024 Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)

from datetime import datetime

from odoo import api, fields, models


class EndingProjetcWizard(models.TransientModel):
    _name = "alterincub.ending.project.wizard"
    _description = "Wizard Fin d'accompagnement"

    @api.model
    def _default_partner_id(self):
        return self.env.context.get("active_id")

    @api.model
    def _default_stop_date(self):
        partner_id = self.env["res.partner"].browse(self.env.context.get("active_id"))
        if partner_id and partner_id.stop_date:
            return partner_id.stop_date
        return datetime.now()

    partner_id = fields.Many2one(
        comodel_name="res.partner",
        string="Projet",
        required=True,
        default=_default_partner_id,
    )

    stop_date = fields.Date(
        string="Date de fin d’accompagnement", required=True, default=_default_stop_date
    )

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------
    def set_ending_project(self):
        self.partner_id.write(
            {
                "stop_date": self.stop_date,
                "project_state": "9_done",
            }
        )

    # ------------------------------------------------------
    # Common functions
    # ------------------------------------------------------
